CB::MJYMD
C
      SUBROUTINE MNTMD( ITIC, IYR, IMON, IDAY, IHR, IMN )
C
C********1*********2*********3*********4*********5*********6*********7**
C
C NAME:             MJYMD
C VERSION:          9303.16
C WRITTEN BY:       M. SCHENEWERK
C PURPOSE:          CONVERT MODIFIED JULIAN DATE TO CALENDAR DATE
C
C INPUT PARAMETERS FROM THE ARGUEMENT LIST:
C -----------------------------------------
C TIMEH             MODIFIED JULIAN DATE
C
C OUTPUT PARAMETERS FROM ARGUEMENT LIST:
C --------------------------------------
C IYR               YEAR
C IMON              MONTH
C IDAY              DAY
C
C
C LOCAL VARIABLES AND CONSTANTS:
C ------------------------------
C
C GLOBAL VARIABLES AND CONSTANTS:
C ------------------------------
C
C
C       THIS MODULE CALLED BY: GENERAL USE
C
C       THIS MODULE CALLS:
C
C       INCLUDE FILES USED:
C
C       COMMON BLOCKS USED:       
C
C       REFERENCES:            DUFFETT-SMITH, PETER  1982, "PRACTICAL
C                              ASTRONOMY WITH YOUR CALCULATOR", 2ND
C                              EDITION, CAMBRIDGE UNIVERSITY PRESS,
C                              NEW YORK, P.9
C
C       COMMENTS:              
C
C********1*********2*********3*********4*********5*********6*********7**
C::MODIFICATION DATE
C::9303.02, MSS, LIBRARY STANDARD
C::9303.16, MSS, DATE ONLY.  SEPARATE ROUTINE, DAYHMS, FOR TIME.
C********1*********2*********3*********4*********5*********6*********7**
CE::MJYMD
C
      IMPLICIT DOUBLE PRECISION(A-H, O-Z)
C
      INTEGER A, B, C, D, E, G, I, TIMEH
C
C........  0.0  EXPLICIT INITIALIZATION
C

C
C........  1.0  CONVERT DATE
C

      IMN = MOD(ITIC,60)
      TIMEH = ITIC/60
     
      IHR = MOD (TIMEH,24)
      TIMEH = TIMEH/24

      I=  TIMEH + 2400001
      IF( I.GT.2299160 ) THEN
        A= (I - 1867216.25D0)/36524.25D0
      ELSE
        A=  I
      ENDIF
      B=  I + 1 + A - DINT( A*0.25D0 )
      C=  B + 1524
      D=  (C - 122.1D0)/365.25D0
      E=  365.25D0*D
      F=  0.D0
      G=  (C - E)/30.6001D0
C
      I=  30.6001D0 * G
      IDAY=  DINT(C - E + F - I)
C
      IF( G .GT. 13.5D0 ) THEN
        IMON= G - 13.0D0
      ELSE
        IMON=  G - 1.0D0
      ENDIF
C
      IF( IMON .GT. 2.5D0 ) THEN
        IYR= D - 4716.0D0
      ELSE
        IYR=  D - 4715.0D0
      ENDIF
C
      RETURN
      END
